import os
from urllib.request import urlopen

from bs4 import BeautifulSoup


def update_packages():
    # Fetches HTML that lists all standard Python 3 (latest) packages
    soup = BeautifulSoup(
        urlopen('https://docs.python.org/3/py-modindex.html').read(),
        'html.parser',
    )

    # Creates a list of packages
    packages = []
    for code in soup.find_all('code'):
        if 'xref' in code['class']:
            package = code.text

            # Some packages are listed with submodules, so we need to filter
            # those out to avoid including repeated entries
            if '.' in package:
                dot = package.find('.')
                package = package[0:dot]
            if package not in packages:
                packages.append(package)

    # Records the list in a file with an entry per line
    packages_list = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                                 'packages.txt')
    with open(packages_list, 'w') as fp:
        for package in packages:
            fp.write(package + '\n')


if __name__ == '__main__':
    update_packages()
